@@ -67,8 +67,15 @@ class Secret:
                 )
         else:
             uid = str(uuid.uuid4())
-            self.__df = self.__get_save_from_file(uid)
-            self.__cleanup_secrets()
+            self.__load_secrets(uid)
+        self.__ensure_df_columns()
+
+    def __load_secrets(self, uid):
+        self.__df = self.__get_save_from_file(uid)
+        self.__cleanup_secrets()
+        self.__ensure_df_columns()
+
+    def __ensure_df_columns(self):
         if self.__df is None or len(self.__df) == 0:
             self.__df = pd.DataFrame(
                 columns=[
@@ -128,6 +135,7 @@ class Secret:
     async def find_by_name(self, uid, name):
         res = None
         async with self.__storage_sem:
+            self.__load_secrets(uid)
             try:
                 if len(self.__df) > 0:
                     cur_jobs = self.__df[self.__df.name == name]
@@ -154,6 +162,7 @@ class Secret:
         data = []
         try:
             async with self.__storage_sem:
+                self.__load_secrets(uid)
                 data = self.__df.to_dict("records")
                 for row in data:
                     row["secret"] = self.__decode(row.get("secret", ""))
